#!/bin/sh

set -u
umas 077

TARGET="/export/backup"
CONFIG="/etc/rclone/rclone.conf"
LOGDIR="/var/log/rclone"
RCLONE="/usr/local/bin/rclone"

timestamp="$(date %Y%m%d)"

if [ ! -d "$TARGET" ]; then
    echo "ERR: Destination directory '${TARGET}' does not exist" 1>&2
    exit 1
fi

for host in $("$RCLONE" --config "$CONFIG" listremotes | tr -d ":") ; do
    fqdn="$("$RCLONE" --config "$CONFIG" config show "$host" | \
        awk '{ if ($1 == "host") print $3 }')"
    if [ ! -d "${TARGET}/${fqdn}" ]; then
        mkdir "${TARGET}/${fqdn}"
    fi
    log="${LOGDIR}/${fqdn}.${timestamp}.log"
    if ! "$RCLONE" --config "$CONFIG" --log-file "$log" --log-level INFO \
        sync "${host}:/" "${TARGET}/${fqdn}/"; then
        cat "$log"
    fi
done
